SystemOrganization addCategory: #ScriptLoader20!

Object subclass: #Loader
	instanceVariableNames: ''
	classVariableNames: 'PackagesBeforeLastLoad'
	poolDictionaries: ''
	category: 'ScriptLoader20'!

!Loader commentStamp: 'LaurentLaffont 3/4/2011 22:44' prior: 0!
I'm an abstract class which collect some infos about package and system (versions, dirty).
#currentChangedPackages instance method and #currentMajorVersionNumber class are missing and provided by my wellknown subclass ScriptLoader (see ScriptLoader comment).


Stef: This is a class that was extracted from scriptLoader because I want to slowly get in place a loader infrastructure based on Metacello.!

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
packageToBeTestedFolderName

	^ 'packages-to-be-tested'! !

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
waitingCacheFolder
	^ (FileDirectory default directoryNamed: self packageToBeTestedFolderName)
		assureExistence;
		yourself

	! !

!Loader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2010 17:41'!
allCurrentVersions
	"self new allCurrentVersions"
	
	| copies names |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	names := copies collect:
		[:ea |  ea ancestry ancestorString ].
	^ names reject: #isEmpty! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:51'!
currentChangedPackages
	"self new currentChangedPackages" 
	
	^  self currentPackages select: [:each |
		each needsSaving or: [
			(PackagesBeforeLastLoad includes: each ancestry ancestorString) not ] ]! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumber

	^ self class currentMajorVersionNumber ! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumberWithoutDot
	"self new currentMajorVersionNumberWithoutDot"
	^ self class currentMajorVersionNumber asString copyWithout: $.! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:42'!
currentVersionsToBeSaved
	"self new currentVersionsToBeSaved"
	
	^ self allCurrentVersions reject: [ :each |
		self packagesNotToSavePatternNames
			anySatisfy: [ :p | p match: each ] ]! !

!Loader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 9/10/2010 17:51'!
diffPackages
	"return a list of packages that are new. They can be dirty or not."
	"self new diffPackages"
	 
	| diff |
	diff := Set new.
	self currentVersionsToBeSaved do: [:each |
		(PackagesBeforeLastLoad includes: each) ifFalse: [diff add: each]].
	^ diff
	! !

!Loader methodsFor: 'initialize' stamp: 'StephaneDucasse 9/10/2010 17:49'!
initialize
	super initialize.
	PackagesBeforeLastLoad ifNil: [ PackagesBeforeLastLoad := Set new ]! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
markPackagesBeforeNewCodeIsLoaded
	"Use this method to keep a log of all the packages that were loaded before loading new code. This will help the system to perform a diff and know after what to publish."
	
	"self new markPackagesBeforeNewCodeIsLoaded"
	
	PackagesBeforeLastLoad := self currentVersionsToBeSaved! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:40'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
		).! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
resetPackagesBeforeLastLoad
	PackagesBeforeLastLoad := Set new! !

Loader subclass: #ScriptLoader
	instanceVariableNames: 'repository inboxRepository repository39 repositorySqueakTrunk repository310 repositoryTaskForces repositoryMC repositoryTreated'
	classVariableNames: 'CheckImageInSyncWithUpdate CurrentMajorVersionNumber CurrentScriptVersionNumber CurrentUpdateVersionNumber CurrentlyIntegratingChanges LogStream Repository'
	poolDictionaries: 'TextConstants'
	category: 'ScriptLoader20'!

!ScriptLoader commentStamp: 'StephaneDucasse 5/26/2010 20:49' prior: 0!
Pharo Process Description


---
Here is the pharo process.

General points
-----------------------
An enhancement
	- should be added to the bug tracker
	- announced to the mailing-list
	- asked for feedback 
	- results should be added to the BT entry

Fixed tag means ready for integration
Closed tag means integrated

A bug detected
	- discuss via the mailing-list
	- should be added to the bug tracker
	- fix are considered as enh (see point above)

When a fix is fixed it should be either post as cs to the BT entry or in the PharoInbox
as a Slice (a slice is an emtpy package that has as requirement other package composing the fix).

We have three projects:
	Pharo
	PharoInbox
	PharoTreatedInbox

A fix goes either from inbox to treatedInbox or to Pharo.
If a fix does not work it is moved to the TreatedInbox.
If a fix works it is integrated as follow - it will be moved from the Inbox to the TreatedInbox
and integrated and published in the Pharo project

To help browsing multiple repositories:

ScriptLoader new addExtraRepositories


+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Now the integration works in 4 main steps which can be steered by the following expression
ScriptLoader releaseMenu
or via the menu that can be shown/hidden using 
	ScriptLoader showIntegrationMenu
	ScriptLoader hideIntegrationMenu


1.) Start up a recent and clean image
	ScriptLoader new prepareNewUpdate
	
	This step will 
		- load the latest updates
		- load the latest ScriptLoader package from the Pharo repository.
		Indeed when we work on improving the ScriptLoader it may not be published in the update stream. 
		New versions can be available on the server but not part of the latest updates.
		Therefore the process always loads the latest version of scriptloader from the pharo repository.
		This point is important because when an integration failed, you have to check and optionally 
		remove the scriptloader package from the pharo repository.
		
		- check that the update.list (which contains the cs to load the packages) is in sync
		with the image current version. You have to download the latest version using a script like this one.
		Pay attention to update it so that it reflects the right version (ie 1.0, 1.1, 1.2...)
		     scp -p LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/updates.list .
		- snapshot the package version to detect dirty or changed but non dirty packages.

2.) Apply changes

	ScriptLoader new doneApplyingChanges
	
	This step will 
		- create an update method with can trigger the load of the packages and some pre/post actions
		- create a script method with describes all the package versions and it used by the update methods
		- save all the packages that are different (except some filtered packages)	
		into a local folder named package-to-be-tested.
		ScriptLoader, SLICE*.... and a couple of other packages are not considered to be included in the script method
			(check method packagesNotToSavePatternNames)
		

3.) Verify changes
	==> in a ***new*** image (in the current folder) execute:
	ScriptLoader new verifyNewUpdate

	This step will 
		- load in any order (so may break) the package previously saved
		in the packages to be tested.
		- this step is important because you may get simple changes with unexpected side effects and that 
		may break the load.
		

4.) If there are problems go to 2.) to fix them, else:
	ScriptLoader new publishChanges

	This step will
		- generate a new cs file whose purpose is to load the given version of the scriptloader and trigger the 
		correct update method.
		- add the name of the cs file to the end of the updates.list file local to the disc
		- copy all the package from the local directory to the Pharo
		
	After the updates.list and the cs file should be manually uploaded to the ftp (see below) 
	   scp "$1" LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/
	

5) in case of problems.
Think that if you pass the step 4 you may have a scriptLoader version that got published and that is reloaded 
during the first step.



CurrentMajorVersionNumber should contains a string '1.0', '1.1'....
This string will determine on which folder on the server the updates.list should be loaded.
	i.e., updates/pharo1.0, updates/pharo1.1 ....

--- Not to forget ---
To change the release stream
add a new method for each releaseStream
	ScriptLoader toPharoOne
	ScriptLoader toPharoOneDotOne
!

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 9/10/2010 17:28'!
checkImageInSyncWithUpdate
	"most of the time you want to make sure that your image is in sync with the latest item of the update.list
	but in some cases you do not to get forced to have this behavior."
	
	^ CheckImageInSyncWithUpdate ifNil: [CheckImageInSyncWithUpdate := true]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate: aBoolean

	CheckImageInSyncWithUpdate := aBoolean! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:15'!
currentMajorVersionNumber

	^ CurrentMajorVersionNumber ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:12'!
currentMajorVersionNumber: aNumber

	CurrentMajorVersionNumber := aNumber! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:06'!
currentlyIntegratingChanges

	CurrentlyIntegratingChanges isNil ifTrue: [self hideIntegrationMenu].
	^ CurrentlyIntegratingChanges! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:32'!
defaultMCWaitingFolder
	"self defaultMCWaitingFolder" 
	
	^ MCDirectoryRepository new directory: self waitingCacheFolder! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			(self new)
				installGofer;
				gofer ]! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
hideIntegrationMenu

	CurrentlyIntegratingChanges := false.! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'MarcusDenker 4/24/2012 18:10'!
initialize
	self flag: #shouldRemoveNumber.
	CurrentMajorVersionNumber :=  2.0! !

!ScriptLoader class methodsFor: 'source' stamp: 'CamilloBruni 12/16/2011 14:07'!
latestSource: packageName location: location

  | contents versionName zip |
  
  versionName := location, '/', (self latestVersionOf: packageName location: location).
  contents := ZnClient new
		systemPolicy;
		beOneShot;
		url: versionName;
		ifFail: [ :exception | self error: 'Cannot access latest source: ' , exception printString ];
		get.
    
  zip := ZipArchive new.
  zip readFrom: contents readStream.
  ^  (zip memberNamed: 'snapshot/source.st') contents.! !

!ScriptLoader class methodsFor: 'source' stamp: 'PavelKrivanek 9/30/2010 11:11'!
latestVersionOf: packageName location: location

  | repository sortMczs fileToLoad | 
  
  repository := MCHttpRepository location: location user: '' password: ''.
  sortMczs := [:a :b |
    [(a findBetweenSubStrs: #($.)) allButLast last asInteger > (b  
      findBetweenSubStrs: #($.)) allButLast last asInteger]
    on: Error do: [:ex | false]].
  
  fileToLoad := (repository readableFileNames asSortedCollection: sortMczs) detect: 
    [:file | file beginsWith: (packageName, '-')].
  
  ^ fileToLoad! !

!ScriptLoader class methodsFor: 'private' stamp: 'al 11/1/2008 20:03'!
loadLatestPackage: aString from: aPath
	| repository |
	
	repository := MCHttpRepository
		location: aPath
		user:  ''
		password: ''.
	self loadLatestPackage: aString fromRepository: repository! !

!ScriptLoader class methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
loadLatestPackage: aString fromRepository: aRepository
	| versionsBlock versions tries |
	
	versionsBlock := [ (aRepository allVersionNames select: [ :each |
		each beginsWith: aString ])
		asSortedCollection: [ :a :b |
			(a copyAfterLast: $.) asNumber <= (b copyAfterLast: $.) asNumber]].
	versions := versionsBlock value.
	tries := 0.
	[ versions isEmpty and: [ tries < 3 ] ] whileTrue: [
		versions := versionsBlock value.
		tries := tries + 1 ].
	versions isEmpty ifTrue: [ self error: 'problems when accessing squeaksource' ].
	
	aRepository versionReaderForFileNamed: (versions last , '.mcz') do: [:reader | | version |
		version := reader version.
		version load.
		version workingCopy repositoryGroup addRepository: aRepository]! !

!ScriptLoader class methodsFor: 'private' stamp: 'StephaneDucasse 8/21/2011 16:01'!
loadLatestPackage: aString fromSqueaksource: aDirectoryName
	" self loadLatestPackage: 'ScriptLoader' fromSqueaksource: 'Pharo' "

	self loadLatestPackage: aString from: self rootURLString, aDirectoryName
	! !

!ScriptLoader class methodsFor: 'menu' stamp: 'FernandoOlivero 4/12/2011 10:14'!
menuCommandOn: aBuilder 
	<worldMenu> 
	
	(aBuilder item: #'Integrator Menu')
		order: 1.5;
		precondition: [self currentlyIntegratingChanges];
		parent: #System;
		icon: self theme smallAuthoringToolsIcon;
		action: [ScriptLoader releaseMenu]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 11/9/2010 18:39'!
releaseMenu
	"self releaseMenu"
	|symbol|
	symbol := UIManager default
		chooseFrom: #('1- Prepare new update'
		                        '2- Save new image for testing (optional)'
						'3- Freeze changes: packages will be saved (required)'
						'4- Verify new update (open the mother image in the same folder) (optional)'
						'5- Publish changes')
		values: #(prepareNewUpdate saveImageForRunningTests doneApplyingChanges verifyNewUpdate publishChanges).
	symbol ifNotNil: [ScriptLoader new perform: symbol]! !

!ScriptLoader class methodsFor: 'public' stamp: 'adrian-lienhard 6/6/2009 11:46'!
resetLogStream
	LogStream := nil! !

!ScriptLoader class methodsFor: 'private' stamp: 'StephaneDucasse 8/21/2011 16:29'!
rootURLString 

	^ 'http://ss3.gemstone.com/ss/'! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
showIntegrationMenu

	CurrentlyIntegratingChanges := true.! !

!ScriptLoader class methodsFor: 'menu' stamp: 'FernandoOlivero 4/12/2011 10:14'!
theme
	^ UITheme current ! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 2/25/2010 18:22'!
CSForLastUpdate: aString
	"ScriptLoader new CSForLastUpdate: 'cleanUpMethods'"
	
	| str updateNumber filename|
	updateNumber := self getLatestUpdateNumber.
	filename := updateNumber asString, '-Pha-', aString, '.cs'.
	FileDirectory default 
		forceNewFileNamed:  filename
		do: [ :stream | 
					self 
						generateCS: self latestScriptLoaderPackageIdentificationString
						fromUpdate: updateNumber on: stream].
	^ filename! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2010 22:31'!
CSForLastUpdateAndPatchUpdatesList: aString
	"ScriptLoader new CSForLastUpdateAndPatchUpdatesList: 'cleanUpMethods'"
	| filename |
	filename := self CSForLastUpdate: aString.
	self updateUpdatesList: aString.
	^ filename ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addExtraRepositories
	
	"self new addExtraRepositories"
	
	self addRepository39ToAllPackages.
	self addRepository310ToAllPackages.
	self addRepositoryTaskForcesToAllPackages.
	self addRepositorySqueakTrunkToAllPackages.
	self addRepositoryMCToAllPackages.
	self addRepositoryTreatedToAllPackages.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 21:51'!
addHomeRepositoryToAllPackages
	"self new addHomeRepositoryToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			addRepository: self repositoryTreated ].
		
	MCRepositoryGroup default
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			 addRepository: self repositoryTreated.
	
		
	
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 17:40'!
addHomeRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 10/18/2009 16:11'!
addPackage: aString
	"to be tested" 
	
	| workingCopy |
	PackageInfo registerPackageName: aString.
	workingCopy := MCWorkingCopy forPackage: (MCPackage new name: aString)! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/13/2009 15:48'!
addRepository310ToAllPackages
	"self new addRepository310ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository310
			].
	
	! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/6/2009 17:38'!
addRepository39ToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepository39ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository39
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/14/2009 10:31'!
addRepositoryMCToAllPackages
	
	"self new addRepositoryMCToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryMC
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2009 20:47'!
addRepositorySqueakTrunkToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepositorySqueakTrunkToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositorySqueakTrunk
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/13/2009 15:59'!
addRepositoryTaskForcesToAllPackages
	"self new addRepositoryTaskForcesToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTaskForces
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 10/31/2005 18:01'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addRepositoryTreatedToAllPackages
	"self new addRepositoryTreatedToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTreated
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentDirtyPackages
	"ScriptLoader new allCurrentDirtyPackages"
	"return all the current dirty packages even the ones that we do not want to save"

	
	^  self allCurrentPackages select: [:each | each needsSaving].

	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentPackages
	"ScriptLoader new allCurrentPackages" 
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:26'!
announceOnMailingList
	"
	self new announceOnMailingList"
	|title|
	title := '[update ', self currentMajorVersionNumber asString , '] #', self currentUpdateVersionNumber asString.
UIManager default
	edit: title, String cr, self currentUpdateVersionNumber asString, '
-----

', self commentForCurrentUpdate
	label: title.! !

!ScriptLoader methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
buildConfigurationMapFor: packageNames

	| configurationMap |
	configurationMap := MCConfiguration new.
	configurationMap repositories
		add: self repository;
		add: self inboxRepository.

	packageNames do: [:packageName | | version depArray |
		version := self loadVersionFromFileNamed: packageName.
		depArray := { version package name. version info name. version info id asString. }.
		configurationMap dependencies add: (MCConfiguration dependencyFromArray: depArray)].
	^configurationMap! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'sd 4/20/2012 16:16'!
checkImageIsUptodate

	| stream last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	stream := FileDirectory default oldFileNamed: self updatesListFileName.
	stream contents linesDo: [ :each | last := each ].
	stream close.
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber.
	! !

!ScriptLoader methodsFor: 'ci' stamp: 'sd 4/20/2012 16:06'!
checkImageIsUptodateSilently

	| stream last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	
	stream := (FileDirectory default oldFileOrNoneNamed: self updatesListFileName).
	
	stream
		ifNil: [ stream := FileDirectory default forceNewFileNamed: self updatesListFileName ].
		
	stream contents linesDo: [ :each | last := each ].
	stream close.
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber.
! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 11/13/2010 22:31'!
cleanRepositories
	"self new cleanRepositories"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllRepositories.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 4/6/2012 10:18'!
cleanUpForProduction
	"self new cleanUpForProduction"
	
	"trim MC ancestory information"
	MCVersionInfo allInstances do: [ :each | each instVarNamed: 'ancestors' put: nil ].

	"delete logo"	
	PolymorphSystemSettings showDesktopLogo: false.

	"unload packages"
	Smalltalk globals at: #SUnitUnloader ifPresent:[ :unloader | unloader new unloadAll  ].
	(MCPackage named: 'Announcements-Help') unload.
	(MCPackage named: 'Regex-Help') unload.
	(MCPackage named: 'HelpSystem-Core') unload.
	(MCPackage named: 'FixUnderscores') unload.
	(MCPackage named: 'Deprecated14') unload.
	
	self cleanUpForRelease.
	(MCPackage named: self theScriptLoaderPackageName) unload.
	
	Smalltalk cleanUp: true except: #() confirming: false.
	Smalltalk garbageCollect.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 4/17/2012 10:15'!
cleanUpForRelease
	"self new cleanUpForRelease"

	Author fullName: 'Mr.Cleaner'.
	self cleanUpPackageOrganizer.
	self cleanUpMethods.

	ImageMorph classPool at: #DefaultForm put: (Form extent: 1 @ 1 depth: 1).
	Smalltalk globals
		at: #TTFontDescription
		ifPresent: [ :c | 
			c
				clearDefault;
				clearDescriptions ].
	ExternalDropHandler resetRegisteredHandlers.
	FreeTypeFontProvider current initialize.
	SystemNavigation default
		allObjectsDo: [ :each | 
			(each respondsTo: #releaseCachedState)
				ifTrue: [ each releaseCachedState ] ].
	
	"Remove empty categories, which are not in MC packages, because MC does
	not do this (this script does not make packages dirty)"
	Smalltalk organization removeEmptyCategories.
	Smalltalk
		allClassesAndTraitsDo: [ :class |
			[ :each |
				each
					removeEmptyCategories;
					sortCategories ]
						value: class organization;
						value: class class organization ].
	Smalltalk organization sortCategories.
	Smalltalk garbageCollect.
	Smalltalk cleanOutUndeclared. 
	Smalltalk fixObsoleteReferences.
	Smalltalk cleanUp: true except: #() confirming: false.
	Author reset! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/5/2010 11:12'!
cleanUpMethods
	"Make sure that all methods in use are restarted"
	"ScriptLoader new cleanUpMethods"

	WeakArray restartFinalizationProcess.
	MethodChangeRecord allInstancesDo: [:x | x noteNewMethod: nil].
	WorldState allInstancesDo: [ :ws | ws convertAlarms; convertStepList; resetWorldMenu].
	WorldState allInstancesDo: [ :ws | ws instVarNamed: 'menuBuilder' put: nil ].
	ExternalDropHandler initialize.
	ScrollBar initializeImagesCache.
	GradientFillStyle initPixelRampCache.
	ProcessBrowser initialize.
	Smalltalk garbageCollect.
	Delay startTimerEventLoop! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 12/5/2009 11:19'!
cleanUpPackageOrganizer

	PackageOrganizer default packages
		do: [ :each | 
			each methods isEmpty
				ifTrue: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'! !

!ScriptLoader methodsFor: 'public' stamp: 'MarcusDenker 5/4/2012 16:04'!
commentForCurrentUpdate
 ^ 'Issue 5751:	SUnit-UI Interaction refactor
	http://code.google.com/p/pharo/issues/detail?id=5751
	
Issue 5445:	Broken command-line arguments in 1.4
	http://code.google.com/p/pharo/issues/detail?id=5445'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 14:36'!
compileNewUpdateMethod
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethod)
		classified: 'pharo - updates'! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:13'!
compileNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad)
		classified: 'pharo - updates'
! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 13:26'!
compileScriptMethodWithCurrentPackages: aNumber 
	"ScriptLoader new compileScriptMethodWithCurrentPackages: 9999"
	
	self class compile: 
		(self newGenerateScriptTemplateWithCurrentPackages: aNumber)
		classified: 'pharo - scripts'! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
copyPackagesFromWaitingFolderToHomeRepository
	"self defaultMCWaitingFolder allFileNames"
	"self new copyPackageFromWaitingFolderToHomeRepository"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		self repository storeVersion: version]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'al 11/1/2008 19:49'!
currentPackages
	"self new currentPackages" 
	
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies reject: [:each |
		self packagesNotToSavePatternNames
			anySatisfy: [:p | p match: each package name]].
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:08'!
currentScriptVersionNumber
	^ CurrentScriptVersionNumber! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 9/8/2009 14:41'!
currentUpdateVersionNumber
	^ CurrentUpdateVersionNumber ifNil: [SystemVersion current highestUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 5/29/2006 20:52'!
currentVersions
	"ScriptLoader new currentVersions"
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies collect:
		[:ea |  ea ancestry ancestorString ]! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:46'!
deletePackage: aString

	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	MCWorkingCopy registry removeKey: toRemove package.! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 9/7/2011 21:23'!
doneApplyingChanges
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	
	comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self].
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersion.
	self saveLatestScriptLoaderToWaitingFolder.
	
	self inform: 'Update prepared and ready to be verified.'! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:13'!
doneApplyingChangesSilentlyComment: providedComment preLoad: preload postLoad: postLoad
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	comment := providedComment trimBoth.
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersionSilentlyPreLoad: preload postLoad: postLoad.
	self saveLatestScriptLoaderToWaitingFolder.! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:12'!
doneApplyingChangesSilentlyIssues: issuesToIntegrate preLoad: preload postLoad: postLoad
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	comment := String streamContents: [:stream |
		issuesToIntegrate do: [:each | 
			stream << each name << 'Thanks to ' << each content author email ; lf;lf.
			stream << each url;lf;lf;lf.]].
	comment := comment trimBoth.
	
	"comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self]."
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersionSilentlyPreLoad: preload postLoad: postLoad.
	self saveLatestScriptLoaderToWaitingFolder.
! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 12:33'!
fixObsoleteReferences
	"self new fixObsoleteReferences"
	CompiledMethod allInstances
		do: [ :method | 
			| obsoleteBindings |
			obsoleteBindings := method literals
				select: [ :literal | literal isVariableBinding 
									and: [ literal value isBehavior and: [ literal value isObsolete ]] ].
			obsoleteBindings
				do: [ :binding | 
					| realClass obsName realName |
					obsName := binding value name.
					Transcript
						show: obsName;
						cr.
					realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
					realClass := Smalltalk globals at: realName asSymbol ifAbsent: [ UndefinedObject ].
					binding key: binding key value: realClass ] ].
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [ SystemNavigation default obsoleteBehaviors inspect ]! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 3/14/2010 12:44'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 16:24'!
generateCS: packageInfo fromUpdate: updateNumber on: st
	
	st nextPutAll:
'"Postscript:
Leave the line above, and replace the rest of this comment by a useful one.
Executable statements should follow this comment, and should
be separated by periods, with no exclamation points (!!!!).
Be sure to put any further comments in double-quotes, like this one."

|repository|
repository := MCHttpRepository
                location: ''', self homeRepositoryUrlString,
'''
                user: ''''
                password: ''''.
(repository loadVersionFromFileNamed:' .
	st nextPut: $' ; nextPutAll: packageInfo, '.mcz'') load.'; cr.
	st nextPutAll: 'ScriptLoader new update', (updateNumber) asString; nextPutAll: '.' ; cr.
	st nextPutAll: '!!'.
	^ st contents
! !

!ScriptLoader methodsFor: 'utils' stamp: 'stephane.ducasse 7/4/2009 12:27'!
generateCompleteFixList
	"generateCompleteFixList"
	| stream |
	stream := (FileStream newFileNamed: 'changes-log.txt').
	[ stream nextPutAll: ScriptLoader new logStream contents ] ensure: [ stream close ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 9/7/2011 22:03'!
generateNewUpdateMethod
	"ScriptLoader new generateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, '.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:05'!
generateScriptAndUpdateMethodForNewVersion
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethod.! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:12'!
generateScriptAndUpdateMethodForNewVersionSilentlyPreLoad: preload postLoad: postLoad
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad.
! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 14:41'!
generateScriptTemplateWithAllCurrentPackages
	"ScriptLoader new generateScriptTemplateWithAllCurrentPackages"
	
	| str |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'scriptXXX' ; cr ; cr ; tab.
	str nextPutAll: '| names|'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	self currentVersionsToBeSaved do: 
		[:each |
			str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 18:07'!
generateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '| names |'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'al 11/1/2008 18:15'!
getLatestScriptNumber
	"self new getLatestScriptNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'script*' match: each ].
	upfroms := upfroms collect: [:each | (each asString allButFirst: 6)].
	upfroms := upfroms reject: [:each | '*Log*' match: each ].
	upfroms := upfroms reject: [:each | '*XXX*' match: each ].
	upfroms := upfroms collect: [:each | each asNumber].
	^ upfroms asSortedCollection last
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 4/20/2012 16:16'!
getLatestUpdateNumber
	"self new getLatestUpdateNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'update*' match: each ].
	upfroms := upfroms collect: [:each | [(each asString last: 5) asNumber] on: Error do: [0]].
	^ upfroms asSortedCollection last! !

!ScriptLoader methodsFor: 'accessing' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			self
				installGofer;
				gofer ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'MarcusDenker 4/19/2012 16:58'!
homeRepositoryUrlString
	
	^ self rootURLString, 'Pharo20'! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 8/21/2011 15:23'!
inboxRepository
	^ inboxRepository ifNil: [inboxRepository :=  self inboxRepositoryDefault]
	! !

!ScriptLoader methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 8/21/2011 15:23'!
inboxRepositoryDefault
	^ MCHttpRepository new 
	 	location: self inboxRepositoryUrlString;
		user: '';
		password: ''! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 15:50'!
inboxRepositoryUrlString
	
	^ self rootURLString, 'PharoInbox'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 14:46'!
installRepository: aString for: packageName

	(MCWorkingCopy allManagers select: [:each | each package name = packageName])
		first repositoryGroup
		addRepository: (MCHttpRepository new location: aString ; user: '' ; password: '')
		! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'alain.plantec 2/6/2009 15:49'!
installVersionInfo
	"self new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' translated initialAnswer: '3.9' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	
! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 8/14/2008 16:03'!
latestScriptLoaderPackageIdentificationString
	"ScriptLoader new latestScriptLoaderPackageIdentificationString"
	
	^  self allCurrentVersions detect: [:each | 'ScriptLoader*' match: each ]
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'Jb 10/23/2010 12:14'!
launchUpdate

	UpdateStreamer new updateFromServer! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 18:04'!
launchUpdateSilently

	^ UpdateStreamer new updateFromServerSilently
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'MarcusDenker 4/19/2012 17:33'!
loadLatestScriptloader
	"self new loadLatestScriptloader"
	
	self class 
		loadLatestPackage: 'ScriptLoader', self currentMajorVersionNumberWithoutDot 
		fromSqueaksource: 'Pharo20' 
	

! !

!ScriptLoader methodsFor: 'private' stamp: 'CamilloBruni 12/16/2011 14:07'!
loadLatestUpdateList
	"fetch the latest version of the update.list on the server"
	
	| result listToUse lastUpdate |
	result := ZnClient new
		systemPolicy;
		beOneShot;
		accept: ZnMimeType text;
		url: (UpdateStreamer new updateFolderURL, self updatesListFileName);
		ifFail: [ :exception | self error: 'Cannot access update server: ' , exception printString ];
		get.
	(listToUse := result lines) isEmpty 
		ifTrue: [ self error: 'Update list is empty' ].			
	lastUpdate := listToUse last.
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			FileDirectory default
				forceNewFileNamed: self updatesListFileName
				do: [:stream | stream nextPutAll: result ] ]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 18:06'!
loadLatestUpdateListSilently
	"fetch the latest version of the update.list on the server"
	
	| result listToUse lastUpdate |
	(result := ZnEasy get: UpdateStreamer new updateFolderURL, self updatesListFileName) isSuccess
		ifFalse: [ self error: 'Cannot access update server' ].
	listToUse := result contents.			
	listToUse linesDo: [:each | lastUpdate := each].
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			FileDirectory default
				forceNewFileNamed: self updatesListFileName
				do: [:stream | stream nextPutAll: listToUse]]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'StephaneDucasse 12/14/2011 21:46'!
loadOneAfterTheOther: aCollection merge: aBoolean
	
	(self newerVersionsIn: aCollection)
		do: [:fn | | loader |
			loader := aBoolean
				ifTrue: [ MCVersionMerger new ]
				ifFalse: [ MCVersionLoader new].
			loader addVersion: (self repository loadVersionFromFileNamed: fn).
			aBoolean
				ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
							request merger conflicts isEmpty
								ifTrue: [request resume: true]
								ifFalse: [request pass]]]
				ifFalse: [loader load]].
	

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'adrian_lienhard 2/21/2009 13:40'!
loadOneAfterTheOther: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadOneAfterTheOther: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			self loadOneAfterTheOther: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
loadPackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		version load]! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'michael.rueger 1/13/2009 15:26'!
loadTogether: aCollection merge: aBoolean
	| loader |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	(self newerVersionsIn: aCollection)
		do: [:fn | loader addVersion: (self loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader hasVersions ifTrue: [loader load]]

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 5/10/2008 12:41'!
loadTogether: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadTogether: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			 self loadTogether: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'private' stamp: 'michael.rueger 1/13/2009 15:25'!
loadVersionFromFileNamed: fn
	| version |
	version := self repository loadVersionFromFileNamed: fn.
	^version
		ifNil: [self inboxRepository loadVersionFromFileNamed: fn]! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 4/4/2008 14:47'!
log: aString

	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/15/2008 18:30'!
logContents

	^ self logStream contents! !

!ScriptLoader methodsFor: 'log' stamp: 'adrian_lienhard 3/16/2009 21:30'!
logStream
	^ LogStream ifNil: [
		LogStream := ReadWriteStream on: (String new: 1000)]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
mergePackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles
		do: [ :name | | version |
			version := self class defaultMCWaitingFolder  versionFromFileNamed: name.
			version merge.
			]! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 9/7/2011 22:03'!
newGenerateNewUpdateMethod
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:13'!
newGenerateNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := preload reset contents asString.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab ].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := postLoad reset contents asString. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab ].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:25'!
newGenerateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	"this version change the script to only "
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '^ '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr'.
	^ str contents! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 10/13/2005 21:44'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		MCWorkingCopy allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ScriptLoader methodsFor: 'utils' stamp: 'sd 2/4/2008 16:09'!
openWindow: contents label: aLabel

	StringHolder new 
		contents: contents ;
		openLabel: aLabel! !

!ScriptLoader methodsFor: 'private' stamp: 'EstebanLorenzano 4/25/2012 17:03'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
			'*OB-*'
			'OmniBrowser*'
			'ConfigurationOf*'
		).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:23'!
prepareNewUpdate
	self launchUpdate.
	self loadLatestScriptloader.
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodate ifFalse: [self loadLatestUpdateList].
	self checkImageIsUptodate ifFalse: [
		^ self inform: 'Your update.list and your image are not in sync!! Please use a fresh image and download the latest update.list and start over. May be you are doing a rollback and you should remove the bogus ScriptLoader version from the Pharo repository' ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	self inform: 'The new version number is ' , self currentUpdateVersionNumber asString , '. Ready to apply changes now.', String cr, 'You are now running in image ', (FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName)).! !

!ScriptLoader methodsFor: 'ci' stamp: 'sd 4/20/2012 16:06'!
prepareNewUpdateSilently
	"Return nil on error"

	self launchUpdateSilently ifFalse: [ ^ nil ].
	[ self loadLatestScriptloader ]
		on: Warning
		do: [:warning | ^ nil ].
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodateSilently ifFalse: [ self loadLatestUpdateListSilently ].
	self checkImageIsUptodate ifFalse: [ ^ nil ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	^ self currentUpdateVersionNumber! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 1/31/2011 22:17'!
publishChanges
	| username password changescriptname changesetFilename str strings|
	(FileStream isAFileNamed: 'PharoPass.txt') 
		ifTrue: [ str := FileStream fileNamed:  'PharoPass.txt'. 
				strings := str contents substrings.
				username := strings first.
				password := strings second] 
		ifFalse: [ username := UIManager default request: 'Pharo repository login'.
			     password := UIManager default requestPassword: 'Pharo repository password'.].

	self setToRepositoriesPassword: password to: username.
	
	changescriptname := UIManager default request: 'Changeset name (no space)' initialAnswer: 'WhatAsChanged'.
	changesetFilename := self CSForLastUpdateAndPatchUpdatesList: changescriptname.
	self copyPackagesFromWaitingFolderToHomeRepository.
	self announceOnMailingList.
	self inform: 'All packages have been uploaded to the Pharo repository.
Remaining manual steps:
1) ./upFilesXX ',changesetFilename,'
2) ./upFilesXX updatesXX.list
3) Announce new update on mailing list'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 22:30'!
removeAllHTTPRepositories: aColl
	"self new removeAllRepositories: 
			#('http://source.squeakfoundation.org/inbox/'
			 'http://source.squeakfoundation.org/39a/'
			 'http://source.squeakfoundation.org/Balloon/'
			 'http://source.squeakfoundation.org/Compression/'
			 'http://source.squeakfoundation.org/Graphics/'
			  'http://source.wiresong.ca/mc/')"
 
	
	MCWorkingCopy allManagers do: [:each | 
		aColl
			do: [:location | 
					each  repositoryGroup removeHTTPRepositoryLocationNamed: location]].
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:22'!
removeAllRepositories
	"self new removeAllRepositories"
	
	MCWorkingCopy allManagers do: [:each |  each  repositoryGroup initialize].
	MCRepositoryGroup default initialize.
	! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:06'!
removeScriptMethods
	"self new removeScriptMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - scripts') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:04'!
removeUpdateMethods

	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - updates') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 8/21/2011 15:19'!
repository
	^ repository ifNil: [
		repository := MCHttpRepository new
			location: self homeRepositoryUrlString ;
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:48'!
repository310
	^ repository310 ifNil: [
		repository310 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/310';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repository39
	^ repository39 ifNil: [
		repository39 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/39a';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:42'!
repository: aRepository
	repository := aRepository! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/14/2009 10:32'!
repositoryMC
	^ repositoryMC ifNil: [
		repositoryMC := MCHttpRepository new
			location:  'http://source.wiresong.ca/mc';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repositorySqueakTrunk
	^ repositorySqueakTrunk ifNil: [
		repositorySqueakTrunk := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/trunk';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 8/21/2011 15:27'!
repositoryTaskForces
	^ repositoryTaskForces ifNil: [
		repositoryTaskForces := MCHttpRepository new
			location:  self taskForcesRepositoryUrlString;
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/26/2009 07:47'!
repositoryTreated
	^ repositoryTreated ifNil: [
		repositoryTreated := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTreatedInbox';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 16:30'!
rootURLString 

	^ self class rootURLString! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:30'!
saveAsImageAsTestImage
	"Now you can run tests and see and go back to the previous image
	and do that go and back.... then after you can decide to freeze"

	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-imageForTestsFor')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'DamienCassou 9/8/2009 14:42'!
saveAsNewImageWithCurrentReleaseName
	|name|
	name := FileDirectory default
				nextNameFor: ('releasePharo-',  self currentUpdateVersionNumber asString)
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:31'!
saveAsNewImageWithCurrentReleaseNameToPublish
	"If the reload failed and you do not want to lose time reload all the cs and packages... you can now restart from the image saved now"
	
	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-releasePharoToPublish')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'al 11/1/2008 18:33'!
saveChangedPackagesIntoWaitingFolder
	self currentChangedPackages do: [:each |
		self
			saveInToReloadCachePackage: each
			with: self commentForCurrentUpdate]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 11/9/2010 18:38'!
saveImageForRunningTests

	| comment commentQuoted st resuming |
	resuming := false.
	SmalltalkImage current saveSession
		ifFalse: [ resuming := true].
	resuming ifTrue: [
		self saveAsImageAsTestImage.
	
		self inform: 'Now you can use this image named ''Test'' to run the tests and come back to fix problems in the \ previous one and eventually freeze it by selecting the next step, in either one.' withCRs]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/2/2008 00:31'!
saveInToReloadCachePackage: aWorkingCopy with: aMessageString
	self
		savePackage: aWorkingCopy
		in: self class defaultMCWaitingFolder
		with: aMessageString! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/28/2010 20:06'!
saveLatestScriptLoaderToHome
	"self new saveLatestScriptLoaderToHome"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader*' match: each  package name].
	self repository storeVersion: r first newVersion.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:31'!
saveLatestScriptLoaderToWaitingFolder
	"self new saveLatestScriptLoaderToWaitingFolder"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader', self currentMajorVersionNumberWithoutDot, '*' match: each  package name].
	self
		saveInToReloadCachePackage: r first
		with: self commentForCurrentUpdate! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 10/20/2009 11:28'!
savePackage: aWorkingCopy in: aRepository with: aMessageString
	" | sc |
	  sc := self new.
	  sc savePackage: (self new workingCopyFromPackageName: 'ScriptLoader11') 
		in: MCCacheRepository default
		with: 'this is test to automate dirty package saving in cache'"

	aRepository storeVersion: (aWorkingCopy 
		newVersionWithName: aWorkingCopy uniqueVersionName
		message: aMessageString)! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/19/2012 16:47'!
script1! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 11:29'!
script10

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1054.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.119.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-EstebanLorenzano.1131.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.21.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.620.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.356.mcz
Tools-MarcusDenker.817.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.408.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 11:57'!
script11

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1054.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.119.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-EstebanLorenzano.1131.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.21.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-MarcusDenker.622.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.201.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.356.mcz
Tools-MarcusDenker.818.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.408.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 13:35'!
script12

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1054.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.119.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1132.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.22.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-MarcusDenker.622.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.201.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.356.mcz
Tools-MarcusDenker.818.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.408.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 14:06'!
script13

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1054.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1133.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.22.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-MarcusDenker.623.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.202.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.358.mcz
Tools-MarcusDenker.818.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.408.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 14:39'!
script14

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1055.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1133.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.22.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-MarcusDenker.624.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.202.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.358.mcz
Tools-MarcusDenker.818.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 14:53'!
script15

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1055.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1134.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-MarcusDenker.625.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.202.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.358.mcz
Tools-MarcusDenker.819.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 15:24'!
script16

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1055.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1135.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.358.mcz
Tools-MarcusDenker.820.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 15:35'!
script17

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1055.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1136.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.358.mcz
Tools-MarcusDenker.821.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 16:08'!
script18

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1055.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1136.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.62.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.358.mcz
Tools-MarcusDenker.822.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/28/2012 00:08'!
script19

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.325.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1057.mcz
KernelTests-MarcusDenker.395.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.62.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.45.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.358.mcz
Tools-MarcusDenker.822.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/20/2012 16:23'!
script2

	^ 'Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.82.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.322.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated14-EstebanLorenzano.54.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.147.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.70.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.73.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
Kernel-MarcusDenker.1047.mcz
KernelTests-MarcusDenker.391.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1127.mcz
MorphicTests-MarcusDenker.48.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-EstebanLorenzano.18.mcz
NOCompletion-EstebanLorenzano.9.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.617.mcz
RecentSubmissions-MarcusDenker.148.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.18.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.13.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.153.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-EstebanLorenzano.610.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-MarcusDenker.79.mcz
Tests-MarcusDenker.354.mcz
Tools-EstebanLorenzano.811.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.406.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/28/2012 09:23'!
script20

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.325.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1058.mcz
KernelTests-MarcusDenker.395.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.577.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.62.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.45.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.359.mcz
Tools-MarcusDenker.822.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/28/2012 22:16'!
script21

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.325.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1058.mcz
KernelTests-MarcusDenker.395.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.577.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.62.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.45.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.360.mcz
Tools-MarcusDenker.823.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/29/2012 11:19'!
script22

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.105.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1059.mcz
KernelTests-MarcusDenker.396.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.577.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.63.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.150.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.360.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/30/2012 09:55'!
script23

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.105.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1060.mcz
KernelTests-MarcusDenker.396.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.577.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.150.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.360.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/30/2012 14:19'!
script24

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.105.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1062.mcz
KernelTests-MarcusDenker.397.mcz
Keymapping-Core-MarcusDenker.121.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.577.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.360.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.409.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/30/2012 20:44'!
script25

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.106.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1063.mcz
KernelTests-MarcusDenker.397.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.360.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.410.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/30/2012 21:03'!
script26

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.106.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1064.mcz
KernelTests-MarcusDenker.397.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.360.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.410.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/1/2012 11:24'!
script27

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.106.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1064.mcz
KernelTests-MarcusDenker.397.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.626.mcz
RPackage-Core-MarcusDenker.110.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.362.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.410.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/1/2012 16:46'!
script28

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.107.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.232.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1065.mcz
KernelTests-MarcusDenker.397.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1137.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.362.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.410.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/1/2012 19:05'!
script29

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.326.mcz
CompilerTests-MarcusDenker.107.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.233.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1065.mcz
KernelTests-MarcusDenker.397.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1138.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.362.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.410.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/24/2012 18:17'!
script3

	^ 'Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.82.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.322.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated14-EstebanLorenzano.54.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.147.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.70.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.73.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
Kernel-MarcusDenker.1049.mcz
KernelTests-MarcusDenker.392.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1127.mcz
MorphicTests-MarcusDenker.48.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-EstebanLorenzano.18.mcz
NOCompletion-EstebanLorenzano.9.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.617.mcz
RecentSubmissions-MarcusDenker.148.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.18.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.13.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.153.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-EstebanLorenzano.610.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-MarcusDenker.79.mcz
Tests-MarcusDenker.354.mcz
Tools-EstebanLorenzano.811.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.406.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/1/2012 20:00'!
script30

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.327.mcz
CompilerTests-MarcusDenker.107.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.233.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1066.mcz
KernelTests-MarcusDenker.397.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1138.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.363.mcz
Tools-MarcusDenker.824.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/2/2012 09:02'!
script31

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.209.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.327.mcz
CompilerTests-MarcusDenker.107.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.233.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1068.mcz
KernelTests-MarcusDenker.399.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1138.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.363.mcz
Tools-MarcusDenker.825.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/2/2012 14:10'!
script32

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.209.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.327.mcz
CompilerTests-MarcusDenker.107.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.233.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1069.mcz
KernelTests-MarcusDenker.399.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1139.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.262.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.364.mcz
Tools-MarcusDenker.826.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/2/2012 14:57'!
script33

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.327.mcz
CompilerTests-MarcusDenker.107.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.233.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1069.mcz
KernelTests-MarcusDenker.400.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1139.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.264.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.364.mcz
Tools-MarcusDenker.827.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/3/2012 09:37'!
script34

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.327.mcz
CompilerTests-MarcusDenker.107.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.234.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1069.mcz
KernelTests-MarcusDenker.400.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1139.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.264.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.203.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.365.mcz
Tools-MarcusDenker.829.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/3/2012 10:38'!
script35

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.328.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.234.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1070.mcz
KernelTests-MarcusDenker.400.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1139.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.264.mcz
NautilusCommon-MarcusDenker.64.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.15.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.613.mcz
System-Text-MarcusDenker.204.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.365.mcz
Tools-MarcusDenker.830.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/4/2012 10:23'!
script36

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.328.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-MarcusDenker.10.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.234.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1072.mcz
KernelTests-MarcusDenker.400.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1139.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.265.mcz
NautilusCommon-MarcusDenker.65.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.17.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.616.mcz
System-Text-MarcusDenker.204.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.365.mcz
Tools-MarcusDenker.830.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/4/2012 10:47'!
script37

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.328.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-MarcusDenker.10.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.234.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1072.mcz
KernelTests-MarcusDenker.400.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1139.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.265.mcz
NautilusCommon-MarcusDenker.65.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.10.mcz
System-Debugging-MarcusDenker.17.mcz
System-Download-MarcusDenker.78.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.617.mcz
System-Text-MarcusDenker.204.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.367.mcz
Tools-MarcusDenker.830.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/4/2012 12:53'!
script38

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.328.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-MarcusDenker.10.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.236.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1072.mcz
KernelTests-MarcusDenker.400.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1139.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.265.mcz
NautilusCommon-MarcusDenker.65.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.6.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.12.mcz
System-Debugging-MarcusDenker.17.mcz
System-Download-MarcusDenker.78.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.617.mcz
System-Text-MarcusDenker.204.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.369.mcz
Tools-MarcusDenker.832.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/4/2012 13:22'!
script39

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.328.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-MarcusDenker.10.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.236.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1074.mcz
KernelTests-MarcusDenker.402.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1141.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.265.mcz
NautilusCommon-MarcusDenker.65.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.6.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.12.mcz
System-Debugging-MarcusDenker.17.mcz
System-Download-MarcusDenker.78.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.617.mcz
System-Text-MarcusDenker.204.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.370.mcz
Tools-MarcusDenker.832.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 4/25/2012 16:20'!
script4

	^ 'Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.82.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.322.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.70.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.73.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
Kernel-MarcusDenker.1049.mcz
KernelTests-MarcusDenker.392.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1127.mcz
MorphicTests-MarcusDenker.48.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-EstebanLorenzano.18.mcz
NOCompletion-EstebanLorenzano.9.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.617.mcz
RecentSubmissions-MarcusDenker.148.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.18.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.13.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.153.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-EstebanLorenzano.610.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-MarcusDenker.79.mcz
Tests-MarcusDenker.354.mcz
Tools-EstebanLorenzano.811.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.406.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/4/2012 14:05'!
script40

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.328.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-MarcusDenker.95.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-MarcusDenker.10.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.237.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1075.mcz
KernelTests-MarcusDenker.403.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1141.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.265.mcz
NautilusCommon-MarcusDenker.65.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.6.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.12.mcz
System-Debugging-MarcusDenker.17.mcz
System-Download-MarcusDenker.78.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.618.mcz
System-Text-MarcusDenker.204.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.370.mcz
Tools-MarcusDenker.832.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 5/4/2012 16:05'!
script41

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.210.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-MarcusDenker.60.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.328.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-MarcusDenker.95.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.6.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-MarcusDenker.10.mcz
FileSystem-Disk-MarcusDenker.8.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-MarcusDenker.8.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.237.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.53.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1075.mcz
KernelTests-MarcusDenker.403.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.13.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-MarcusDenker.4.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.578.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.142.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1141.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-MarcusDenker.265.mcz
NautilusCommon-MarcusDenker.65.mcz
NautilusRefactoring-MarcusDenker.27.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.75.mcz
Polymorph-Widgets-MarcusDenker.628.mcz
RPackage-Core-MarcusDenker.112.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-MarcusDenker.56.mcz
RecentSubmissions-MarcusDenker.152.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.46.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-MarcusDenker.18.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.21.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.16.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-MarcusDenker.19.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.3.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.6.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.12.mcz
System-Debugging-MarcusDenker.17.mcz
System-Download-MarcusDenker.78.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.618.mcz
System-Text-MarcusDenker.204.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.370.mcz
Tools-MarcusDenker.832.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.411.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 4/25/2012 17:08'!
script5

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.82.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.322.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.70.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.73.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1049.mcz
KernelTests-MarcusDenker.392.mcz
Keymapping-Core-EstebanLorenzano.117.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-EstebanLorenzano.1131.mcz
MorphicTests-MarcusDenker.48.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-EstebanLorenzano.20.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.620.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.148.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.18.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.13.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.153.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-EstebanLorenzano.610.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.354.mcz
Tools-EstebanLorenzano.814.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.406.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/26/2012 15:41'!
script6

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.323.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1050.mcz
KernelTests-MarcusDenker.392.mcz
Keymapping-Core-EstebanLorenzano.117.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-EstebanLorenzano.1131.mcz
MorphicTests-MarcusDenker.48.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-EstebanLorenzano.20.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.620.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.13.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.355.mcz
Tools-MarcusDenker.815.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.406.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 09:56'!
script7

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.323.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1051.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-EstebanLorenzano.117.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-EstebanLorenzano.1131.mcz
MorphicTests-MarcusDenker.48.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-EstebanLorenzano.20.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.620.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.13.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.356.mcz
Tools-MarcusDenker.815.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.406.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 10:37'!
script8

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.323.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1051.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.119.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-EstebanLorenzano.1131.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-EstebanLorenzano.20.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.620.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.13.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.356.mcz
Tools-MarcusDenker.815.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.406.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/27/2012 11:02'!
script9

	^ 'AST-Core-EstebanLorenzano.93.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.83.mcz
BalloonTests-MarcusDenker.1.mcz
Collections-Abstract-MarcusDenker.160.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.66.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.207.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.77.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.131.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-Integrator.557.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-MarcusDenker.324.mcz
CompilerTests-marcusDenker.104.mcz
Compression-StephaneDucasse.93.mcz
CompressionTests-MarcusDenker.2.mcz
EmergencyEvaluator-MarcusDenker.25.mcz
EventModel-StephaneDucasse.1.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-EstebanLorenzano.8.mcz
FileSystem-Disk-EstebanLorenzano.6.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-EstebanLorenzano.6.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.231.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-MarcusDenker.574.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-MarcusDenker.131.mcz
Graphics-Display Objects-MarcusDenker.71.mcz
Graphics-External-MarcusDenker.10.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-EstebanLorenzano.52.mcz
Graphics-Primitives-MarcusDenker.74.mcz
Graphics-Resources-MarcusDenker.13.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.27.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1053.mcz
KernelTests-MarcusDenker.393.mcz
Keymapping-Core-MarcusDenker.119.mcz
Keymapping-Pragmas-EstebanLorenzano.10.mcz
Keymapping-Settings-EstebanLorenzano.61.mcz
Keymapping-Shortcuts-EstebanLorenzano.54.mcz
Keymapping-Tools-Spec-EstebanLorenzano.2.mcz
MenuRegistration-StephaneDucasse.37.mcz
Monticello-MarcusDenker.575.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.140.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-EstebanLorenzano.1131.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-StephaneDucasse.20.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.27.mcz
NECompletion-MarcusDenker.21.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-EstebanLorenzano.258.mcz
NautilusCommon-EstebanLorenzano.60.mcz
NautilusRefactoring-EstebanLorenzano.25.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.73.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.51.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-StephaneDucasse.64.mcz
NetworkTests-StephaneDucasse.64.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.75.mcz
PluggableTextMorphWithLimits-EstebanLorenzano.9.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.10.mcz
Polymorph-Tools-Diff-StephaneDucasse.73.mcz
Polymorph-Widgets-EstebanLorenzano.620.mcz
RPackage-Core-EstebanLorenzano.108.mcz
RPackage-SystemIntegration-EstebanLorenzano.90.mcz
RPackage-Tests-EstebanLorenzano.53.mcz
RecentSubmissions-MarcusDenker.149.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.11.mcz
Ring-Core-Kernel-MarcusDenker.44.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.24.mcz
SUnit-Core-EstebanLorenzano.15.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.43.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.16.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-EstebanLorenzano.13.mcz
Spec-Tests-EstebanLorenzano.4.mcz
Spec-Tools-EstebanLorenzano.10.mcz
Spec-Widgets-EstebanLorenzano.17.mcz
StartupPreferences-EstebanLorenzano.34.mcz
System-Announcements-MarcusDenker.1.mcz
System-Applications-EstebanLorenzano.42.mcz
System-BreakPoints-MarcusDenker.4.mcz
System-Change Notification-MarcusDenker.23.mcz
System-Changes-MarcusDenker.135.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.14.mcz
System-Download-EstebanLorenzano.74.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.61.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.154.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.611.mcz
System-Text-MarcusDenker.199.mcz
System-Tools-EstebanLorenzano.81.mcz
Tests-MarcusDenker.356.mcz
Tools-MarcusDenker.815.mcz
ToolsTest-MarcusDenker.denker.22.mcz
Traits-MarcusDenker.407.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.61.mcz
Zinc-HTTP-EstebanLorenzano.253.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/13/2010 22:30'!
setToRepositoriesPassword: aPassword to: aUser
	"self new setToRepositoriesPassword: 'sd' to: 'zork'"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllHTTPRepositories: {self repository locationWithTrailingSlash . self inboxRepository locationWithTrailingSlash}. 
	self repository password: aPassword.
	self repository user: aUser.
	self inboxRepository password: aPassword.
	self inboxRepository user: aUser.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:07'!
setUpdateAndScriptVersionNumbers
	CurrentUpdateVersionNumber := self getLatestUpdateNumber + 1.
	CurrentScriptVersionNumber := self getLatestScriptNumber + 1.! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 11/8/2010 22:09'!
shortImageName
	"should be removed when the version  will be integrated in SmalltalkImage"
	
	^ FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName).! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 15:57'!
taskForcesRepositoryUrlString
	
	^ self rootURLString , 'PharoTaskForces'! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 11/13/2010 22:21'!
theScriptLoaderPackageName
	^'ScriptLoader',  CurrentMajorVersionNumber asString copyWithout: $. ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:58'!
unloadPackage: aString
	"self new unloadPackage: 'Sixx'"
	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'stephane.ducasse 2/6/2009 17:36'!
unloadPackageNamed: aString
	"self new workingCopyFromPackageName: 'CollectionExtensions' "
	
	^ (self workingCopyFromPackageName: aString) unload
	! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'sd 4/20/2012 16:15'!
update20005! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/20/2012 16:24'!
update20006
	"self new update20006"
	self withUpdateLog: 'Issue 5615:	clean up #contextForLocalVariables
	http://code.google.com/p/pharo/issues/detail?id=5615'.
	self loadTogether: self script2 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/24/2012 18:10'!
update20007! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/24/2012 18:10'!
update20008! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/24/2012 18:17'!
update20009
	"self new update20009"
	self withUpdateLog: 'Issue 5564:	Support bit operations on Boolean / Integers
	http://code.google.com/p/pharo/issues/detail?id=5564
	
Issue 5641:	Unload Deprecated14
	http://code.google.com/p/pharo/issues/detail?id=5641'.
	self loadTogether: self script3 merge: false.
	ScriptLoader new unloadPackageNamed: 'Deprecated14'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 4/25/2012 16:21'!
update20010
	"self new update20010"
	self withUpdateLog: 'reintroducing addPackage: so that we can load configuration.'.
	self loadTogether: self script4 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 4/25/2012 17:09'!
update20011
	"self new update20011"
	self withUpdateLog: 'introducing: 

-RPackage
-Spec
-Keymapping
-Refactoring Engine
-AST
-Nautilus

- Issue 5665:	bug on new ecompletion/ocompletion
	http://code.google.com/p/pharo/issues/detail?id=5665
	
- Issue 5671:	Polymorph fixes
	http://code.google.com/p/pharo/issues/detail?id=5671'.
	self loadTogether: self script5 merge: false.
	World resetWorldMenu.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/26/2012 15:41'!
update20012
	"self new update20012"
	ScriptLoader new addHomeRepositoryToAllPackages.
ScriptLoader showIntegrationMenu.
	self withUpdateLog: 'Issue 5686:	Add some primitive testing methods to CompiledMethod
	http://code.google.com/p/pharo/issues/detail?id=5686
	
Issue 5692:	extract startup and shutdown from snapshot:andQuit:
	http://code.google.com/p/pharo/issues/detail?id=5692
	
Issue 5688:	remove #isClosureCompiled
	http://code.google.com/p/pharo/issues/detail?id=5688
	
Issue 5682:	metacelloPlatformAttributes should be updated.
	http://code.google.com/p/pharo/issues/detail?id=5682
	
Issue 5674:	remove more deprecated method
	http://code.google.com/p/pharo/issues/detail?id=5674
	
Issue 5639:	[EventModel] Remove more direct usage of Sensor
	http://code.google.com/p/pharo/issues/detail?id=5639'.
	self loadTogether: self script6 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 09:56'!
update20013
	"self new update20013"
	self withUpdateLog: 'Issue 5700:	Failing test: MethodReferenceTest
	http://code.google.com/p/pharo/issues/detail?id=5700
	
Issue 5687:	remove and clean up CompiledMethod>>#hasNewPropertyFormat
	http://code.google.com/p/pharo/issues/detail?id=5687'.
	self loadTogether: self script7 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 10:37'!
update20014
	"self new update20014"
	self withUpdateLog: 'Issue 5699:	Failing test: EventHandlerTest
	http://code.google.com/p/pharo/issues/detail?id=5699
	'.
	self loadTogether: self script8 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 11:03'!
update20015
	"self new update20015"
	self withUpdateLog: 'Issue 5691:	all sender of #getSourceFor:in: can just use #sourceCode
	http://code.google.com/p/pharo/issues/detail?id=5691
	
Issue 5651:	Fix for Classbuilder (subclasses of CompiledMethod)
	http://code.google.com/p/pharo/issues/detail?id=5651
	
Issue 5690:	CompiledMethod #sourceClass and #sourceSelector
	http://code.google.com/p/pharo/issues/detail?id=5690'.
	self loadTogether: self script9 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 11:30'!
update20016
	"self new update20016"
	self withUpdateLog: 'Issue 5701:	Obsolete Classes in 2.0
	http://code.google.com/p/pharo/issues/detail?id=5701
	
Issue 5708:	Smooth Block code editing in Debugger
	http://code.google.com/p/pharo/issues/detail?id=5708
	
Issue 5689:	remove #checkOKToAdd:at:
	http://code.google.com/p/pharo/issues/detail?id=5689
	
Issue 5707:	Integrate Keymappings-Tests into Pharo2.0
	http://code.google.com/p/pharo/issues/detail?id=5707'.
	self loadTogether: self script10 merge: false.
	Smalltalk tools remove: #messageNames.
ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 11:57'!
update20017
	"self new update20017"
	self withUpdateLog: 'Issue 5684:	Integrate famfam icons
	http://code.google.com/p/pharo/issues/detail?id=5684
	'.
	self loadTogether: self script11 merge: false.
	ThemeIcons initializeIcons.
World resetWorldMenu.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 13:35'!
update20018
	"self new update20018"
	self withUpdateLog: 'Issue 5709:	#getSourceFromFile should not be called from external clients
	http://code.google.com/p/pharo/issues/detail?id=5709
	
Issue 5648:	self world in HaloMorph is nil
	http://code.google.com/p/pharo/issues/detail?id=5648
	
Issue 5666:	Unable to open the menu with one click mouse (again)
	http://code.google.com/p/pharo/issues/detail?id=5666
	
Issue 5619:	PluggableListMorph drag/drop raise DNU
	http://code.google.com/p/pharo/issues/detail?id=5619'.
	self loadTogether: self script12 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 14:06'!
update20019
	"self new update20019"
	self withUpdateLog: 'Issue 5598:	SHParserST80Test>>testObjectClass fails after Magritte is loaded
	http://code.google.com/p/pharo/issues/detail?id=5598
	
Issue 5621:	PackageInfo extensionMethods not gathering all extensions
	http://code.google.com/p/pharo/issues/detail?id=5621
	
Issue 5660:	having more handles*: for keyboard handling
	http://code.google.com/p/pharo/issues/detail?id=5660'.
	self loadTogether: self script13 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 14:39'!
update20020
	"self new update20020"
	self withUpdateLog: 'Issue 5675:	Easy fix in DropListMorph
	http://code.google.com/p/pharo/issues/detail?id=5675
	
Issue 5642:	better tempNamed:
	http://code.google.com/p/pharo/issues/detail?id=5642
	
Issue 5594:	ClassOrganizer use printString for changeSet
	http://code.google.com/p/pharo/issues/detail?id=5594'.
	self loadTogether: self script14 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 14:53'!
update20021
	"self new update20021"
	self withUpdateLog: 'Issue 5584:	File Browser not recognizing cs and st if filename has more than one point
	http://code.google.com/p/pharo/issues/detail?id=5584
	
Issue 5714:	VersionsBrowser for human beings
	http://code.google.com/p/pharo/issues/detail?id=5714
	
Issue 5646:	use a dictionary instead of caseOf:
	http://code.google.com/p/pharo/issues/detail?id=5646
	
'.
	self loadTogether: self script15 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 15:24'!
update20022
	"self new update20022"
	self withUpdateLog: 'Issue 5633:	Cleaning addUpdating: wordingSelector target: target selector: aSymbol argumentList: argList
	http://code.google.com/p/pharo/issues/detail?id=5633
'.
	self loadTogether: self script16 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 15:36'!
update20023
	"self new update20023"
	self withUpdateLog: 'Issue 5718:	Rename in file browser dnu
	http://code.google.com/p/pharo/issues/detail?id=5718

	
Issue 5685:	Add expand all and collapse all to Monticello Changes and Merg
	http://code.google.com/p/pharo/issues/detail?id=5685'.
	self loadTogether: self script17 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/27/2012 16:08'!
update20024
	"self new update20024"
	self withUpdateLog: 'Issue 5719:	Create trait with Nautilus fails
	http://code.google.com/p/pharo/issues/detail?id=5719
	
-> last Nautilus and Spec packages'.
	self loadTogether: self script18 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/28/2012 00:08'!
update20025
	"self new update20025"
	self withUpdateLog: 'Issue 5728:	Add voidCogVMState primitives
	http://code.google.com/p/pharo/issues/detail?id=5728
	
Issue 5727:	add how to use comment to SystemProgressBarMorph
	http://code.google.com/p/pharo/issues/detail?id=5727
	
Issue 5704:	 speed-up unwind-protects a little.
	http://code.google.com/p/pharo/issues/detail?id=5704
	
Issue 5605:	DateAndTimeTest>>testPrintStringNoOffset fails on pharo-one-click
	http://code.google.com/p/pharo/issues/detail?id=5605
	
Issue 5653:	SystemNavigation has unused class variable Default
	http://code.google.com/p/pharo/issues/detail?id=5653'.
	self loadTogether: self script19 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/28/2012 09:24'!
update20026
	"self new update20026"
	self withUpdateLog: 'Issue 5722:	Be able to remove traits from class definition
	http://code.google.com/p/pharo/issues/detail?id=5722
	
Issue 5715:	Enhance the Slice Maker so that is gets the issue title automatically
	http://code.google.com/p/pharo/issues/detail?id=5715
	
Issue 5580:	MCOrganization unload correctly
	http://code.google.com/p/pharo/issues/detail?id=5580'.
	self loadTogether: self script20 merge: false.
	ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/28/2012 22:16'!
update20027
	"self new update20027"
	self withUpdateLog: 'Issue 5731:	Add trait test for a specific failing case
	http://code.google.com/p/pharo/issues/detail?id=5731
	
Issue 5729:	remove #profile from InflateStream
	http://code.google.com/p/pharo/issues/detail?id=572'.
	self loadTogether: self script21 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/29/2012 11:20'!
update20028
	"self new update20028"
	self withUpdateLog: 'Issue 5734:	Clients of CompiledMethod should not call #getSource
	http://code.google.com/p/pharo/issues/detail?id=5734
	
Issue 5735:	add #generateWithSources to MethodNode
	http://code.google.com/p/pharo/issues/detail?id=5735'.
	self loadTogether: self script22 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/30/2012 09:55'!
update20029
	"self new update20029"
	self withUpdateLog: 'Issue 5736:	deprecate #getSourceFor:in:
	http://code.google.com/p/pharo/issues/detail?id=5736
	
Issue 5741:	New version of NautilusCommon
	http://code.google.com/p/pharo/issues/detail?id=5741

Issue 5745:	numArgs, numTemps, endPC & isClean et al
	http://code.google.com/p/pharo/issues/detail?id=5745'.
	self loadTogether: self script23 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/30/2012 14:19'!
update20030
	"self new update20030"
	self withUpdateLog: 'Issue 5749:	Show categories in senders, implementors, etc.
	http://code.google.com/p/pharo/issues/detail?id=5749
	
Issue 5605:	DateAndTimeTest>>testPrintStringNoOffset fails on pharo-one-click
	http://code.google.com/p/pharo/issues/detail?id=5605
	
Issue 5722:	Be able to remove traits from class definition
	http://code.google.com/p/pharo/issues/detail?id=5722'.
	self loadTogether: self script24 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/30/2012 20:45'!
update20031
	"self new update20031"
	self withUpdateLog: 'Issue 5679:	Removing a trait does not remove trait methods from class
	http://code.google.com/p/pharo/issues/detail?id=5679
	
Issue 5737:	cleanup #useClosureBytecodes
	http://code.google.com/p/pharo/issues/detail?id=5737
	
Issue 5752:	Update Keymapping
	http://code.google.com/p/pharo/issues/detail?id=5752'.
	self loadTogether: self script25 merge: false.
	KMRepository reset.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/30/2012 21:03'!
update20032
	"self new update20032"
	self withUpdateLog: 'Issue 5722:	Be able to remove traits from class definition
		http://code.google.com/p/pharo/issues/detail?id=5722'.
	self loadTogether: self script26 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/1/2012 11:24'!
update20033
	"self new update20033"
	self withUpdateLog: 'Issue 5703:	Failing tests related to SystemNavigation
	http://code.google.com/p/pharo/issues/detail?id=5703
	
Issue 5694:	Failing tests related to RPackage
	http://code.google.com/p/pharo/issues/detail?id=5694'.
	self loadTogether: self script27 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/1/2012 16:46'!
update20034
	"self new update20034"
	self withUpdateLog: 'Issue 5754:	Failing tests: #testAllDictionariesAreHealthy
	http://code.google.com/p/pharo/issues/detail?id=5754
	
Issue 5757:	remove expected failure from testMirrorSize
	http://code.google.com/p/pharo/issues/detail?id=5757
	
Issue 5722:	Be able to remove traits from class definition
	http://code.google.com/p/pharo/issues/detail?id=5722
	
Issue 5702:	Undeclareds in 2.0
	http://code.google.com/p/pharo/issues/detail?id=5702'.
	self loadTogether: self script28 merge: false.
	ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/1/2012 19:05'!
update20035
	"self new update20035"
	self withUpdateLog: 'Issue 5762:	Some initialization fixes in WeakFinalizationList
	http://code.google.com/p/pharo/issues/detail?id=5762
	
Issue 5761:	Some initialization fixes in FileDirectory
	http://code.google.com/p/pharo/issues/detail?id=5761
		
Issue 5759:	Some initialization fixes in Graphics-External-Ffenestri
	http://code.google.com/p/pharo/issues/detail?id=5759
	
Issue 5746:	Add announcer property into morph
	http://code.google.com/p/pharo/issues/detail?id=5746
	'.
	self loadTogether: self script29 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/1/2012 20:00'!
update20036
	"self new update20036"
	self withUpdateLog: 'Issue 5740:	Clean up Temp Embedding 1): Traits
	http://code.google.com/p/pharo/issues/detail?id=5740
'.
	self loadTogether: self script30 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/2/2012 09:03'!
update20037
	"self new update20037"
	self withUpdateLog: 'Issue 5763:	ProtoObject>>#~~ cleanup
	http://code.google.com/p/pharo/issues/detail?id=5763
	
Issue 5743:	Cannot load editions of class side methods
	http://code.google.com/p/pharo/issues/detail?id=5743
	
Issue 2063:	NumberTest
	http://code.google.com/p/pharo/issues/detail?id=2063
'.
	self loadTogether: self script31 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/2/2012 14:10'!
update20038
	"self new update20038"
	self withUpdateLog: 'Issue 5775:	add test to trait removal
	http://code.google.com/p/pharo/issues/detail?id=5775
	
Issue 5738:	do allow the same ivar in the hierarchy
	http://code.google.com/p/pharo/issues/detail?id=5738
	
Issue 5742:	BallonMorph shows flyover help using an extra line
	http://code.google.com/p/pharo/issues/detail?id=5742
	
Issue 5667:	Renaming a file just deletes it due to missing #fileNameFromFormattedItem:
	http://code.google.com/p/pharo/issues/detail?id=5667
	
Issue 5773:	Have access to the original event in PLuggableButtonMorph
	http://code.google.com/p/pharo/issues/detail?id=5773'.
	self loadTogether: self script32 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/2/2012 14:57'!
update20039
	"self new update20039"
	self withUpdateLog: 'Issue 5779:	remove testDuplicateInstanceVariableError
	http://code.google.com/p/pharo/issues/detail?id=5779
	
Issue 5767:	[BUG]: Nautilus has re-bound the explore shortcut
	http://code.google.com/p/pharo/issues/detail?id=5767
	
Issue 5768:	[ENH]: Nautilus - Debug test	
	http://code.google.com/p/pharo/issues/detail?id=5768
	
Issue 5724:	integrate Spotlight in Pharo 2.0
	http://code.google.com/p/pharo/issues/detail?id=5724'.
	self loadTogether: self script33 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/2/2012 16:00'!
update20040! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/2/2012 16:00'!
update20041! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/3/2012 09:38'!
update20042
	"self new update20042"
	self withUpdateLog: 'Issue 5777:	Test and workaround for methods with incorrect global literals
	http://code.google.com/p/pharo/issues/detail?id=5777

Issue 5781:	Add nice diff morph to compare to current and compare to version...
	http://code.google.com/p/pharo/issues/detail?id=5781'.
	self loadTogether: self script34 merge: false.
	Compiler recompileAll.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/3/2012 10:38'!
update20043
	"self new update20043"
	self withUpdateLog: ' Issue 5744:	Clean up Temp Embedding 2): DoIts
	http://code.google.com/p/pharo/issues/detail?id=5744'.
	self loadTogether: self script35 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/4/2012 10:23'!
update20044
	"self new update20044"
	self withUpdateLog: 'Issue 5785:	Nautilus: - Fix BreadCrumb plugin - Add Guillermos plugin - Fix Package Removal
	http://code.google.com/p/pharo/issues/detail?id=5785
	
Issue 5784:	Clean FSReference from comments
	http://code.google.com/p/pharo/issues/detail?id=5784
	
Issue 5792:	Fix tempNamed and tempNamedPut
	http://code.google.com/p/pharo/issues/detail?id=5792
	
Issue 5788:	methodsWithUnboundGlobals should search by identity
	http://code.google.com/p/pharo/issues/detail?id=5788
	
Issue 5794:	Move DebuggerMethodMap to Kernel
	http://code.google.com/p/pharo/issues/detail?id=5794'.
	self loadTogether: self script36 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/4/2012 10:48'!
update20045
	"self new update20045"
	self withUpdateLog: 'Issue 5801:	remove #testLiteralsForGlobalBehaviorsAreCorrect
	http://code.google.com/p/pharo/issues/detail?id=5801
	
Issue 5758:	Improve CommandLine handling
	http://code.google.com/p/pharo/issues/detail?id=5758'.
	self loadTogether: self script37 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/4/2012 12:53'!
update20046
	"self new update20046"
	ScriptLoader new addHomeRepositoryToAllPackages.
	self withUpdateLog: 'Issue 5789:	Merge ExpandedSourceFileArray into SourceFileArray (part1 copy methods)
	http://code.google.com/p/pharo/issues/detail?id=5789
	
Issue 5804:	Failing Test:testCommandLineHandlerCondition
	http://code.google.com/p/pharo/issues/detail?id=5804
	
	
Issue 5795:	Merge System-BreakPoints with Tools-Debugger
	http://code.google.com/p/pharo/issues/detail?id=5795'.
	self loadTogether: self script38 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/4/2012 13:22'!
update20047
	"self new update20047"
	self withUpdateLog: 'Issue 5782:	Close ALL windows, no matter if they have unchanged changes
	http://code.google.com/p/pharo/issues/detail?id=5782
	
Issue 5792:	Fix tempNamed and tempNamedPut
	http://code.google.com/p/pharo/issues/detail?id=5792
	
Issue 5790:	Merge ExpandedSourceFileArray into SourceFileArray (part2 install and fix tests)
	http://code.google.com/p/pharo/issues/detail?id=5790'.
	self loadTogether: self script39 merge: false.
	SourceFileArray install.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/4/2012 14:06'!
update20048
	"self new update20048"
	self withUpdateLog: 'Issue 5793:	More flexible special objects array
	http://code.google.com/p/pharo/issues/detail?id=5793
	
Issue 5802:	Clean Embedded Temp Names: CompiledMethodTrailer
	http://code.google.com/p/pharo/issues/detail?id=5802
	
Issue 5791:	Merge ExpandedSourceFileArray into SourceFileArray (part3: remove ExpandedSourceFileArray)
	http://code.google.com/p/pharo/issues/detail?id=5791'.
	self loadTogether: self script40 merge: false.
	Smalltalk specialObjectsArray: Smalltalk primitiveGetSpecialObjectsArray.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 5/4/2012 16:05'!
update20049
	"self new update20049"
	self withUpdateLog: 'Issue 5751:	SUnit-UI Interaction refactor
	http://code.google.com/p/pharo/issues/detail?id=5751
	
Issue 5445:	Broken command-line arguments in 1.4
	http://code.google.com/p/pharo/issues/detail?id=5445'.
	self loadTogether: self script41 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2011 22:22'!
updateUpdatesList: aString
	"ScriptLoader new updateUpdatesList: 'cleanUpMethods'"
	
	| str |
	str := FileDirectory default oldFileNamed: self updatesListFileName.
	[	str
			setToEnd;
			cr;
			nextPutAll: self currentUpdateVersionNumber asString;
			nextPutAll: '-Pha-', aString, '.cs' ]
		ensure: [ str close ]! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 2/10/2011 15:40'!
updatesListFileName

	^ 'updates', (SystemVersion current majorMinor:''), '.list'! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'lr 3/14/2010 21:13'!
verifyNewUpdate
	self repository: self class defaultMCWaitingFolder.
	self class loadLatestPackage: 'ScriptLoader' fromRepository: self repository.
	self perform: ('update' , self getLatestUpdateNumber asString) asSymbol.
	(self confirm: 'Completed loading the new update. Run all test now?')
		ifTrue: [ 
			Author fullName: 'tester'.
			Smalltalk globals at: #TestRunner ifPresent: [ :class | class open model runAll ] ]! !

!ScriptLoader methodsFor: 'private' stamp: 'al 11/1/2008 18:19'!
waitingFolderMCZFiles
	^ self class defaultMCWaitingFolder allFileNames
		reject: [:each | each =  '.DS_Store']! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/24/2008 16:45'!
withUpdateLog: aString

	self logStream nextPutAll: ' ------------------------------------------------------' ; cr.
	self logStream nextPutAll: thisContext sender selector asString. 
	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'sd 3/24/2008 17:31'!
workingCopyFromPackageName: aString
	"self new workingCopyFromPackageName: '39Deprecated' "
	
	|pa|
	pa := MCPackage named: aString.
	^ pa workingCopy 
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 7/8/2006 18:20'!
writeCS: extensionAndNumber forUpdate: updateNumber
	"ScriptLoader new writeCS: '-sd.210' forUpdate: 7037"
	
	self writeCS: extensionAndNumber forUpdate: updateNumber withName: 'changeMe'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 2/25/2010 18:09'!
writeCS: extensionAndNumber forUpdate: updateNumber withName: aSt
	"ScriptLoader new writeCS: '-md.2929' forUpdate: 7049 withName: 'cleanUpMethods'"
	

	FileDirectory default 
		forceNewFileNamed:  updateNumber asString, 'update', aSt, '.cs'
		do: [ :stream | self generateCS: extensionAndNumber fromUpdate: updateNumber on: stream].
! !
ScriptLoader initialize!
